@@ -12,14 +12,6 @@ import time
 import traceback
 import warnings
 
-try:
-    import clr
-    from System.Collections.Generic import List
-except ImportError:  # pragma: no cover
-    if os.name != "posix":
-        warnings.warn("PythonNET is needed to run PyAEDT.")
-    elif sys.version[0] == 3 and sys.version[1] < 7:
-        warnings.warn("EDB requires Linux Python 3.7 or later.")
 from pyaedt import pyaedt_logger
 from pyaedt import settings
 from pyaedt.edb_core import Components
@@ -29,13 +21,21 @@ from pyaedt.edb_core import EdbNets
 from pyaedt.edb_core import EdbSiwave
 from pyaedt.edb_core import EdbStackup
 from pyaedt.edb_core.edb_data.edb_builder import EdbBuilder
+from pyaedt.edb_core.edb_data.padstacks_data import EDBPadstackInstance
 from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
+from pyaedt.edb_core.edb_data.sources import ExcitationDifferential
+from pyaedt.edb_core.edb_data.sources import ExcitationPorts
+from pyaedt.edb_core.edb_data.sources import ExcitationProbes
+from pyaedt.edb_core.edb_data.sources import ExcitationSources
 from pyaedt.edb_core.edb_data.sources import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.edb_core.materials import Materials
 from pyaedt.edb_core.padstack import EdbPadstacks
 from pyaedt.edb_core.stackup import Stackup
-from pyaedt.generic.constants import CutoutSubdesignType
+from pyaedt.generic.clr_module import Convert
+from pyaedt.generic.clr_module import List
+from pyaedt.generic.clr_module import _clr
+from pyaedt.generic.clr_module import edb_initialized
 from pyaedt.generic.constants import SolverType
 from pyaedt.generic.general_methods import env_path
 from pyaedt.generic.general_methods import env_path_student
@@ -51,17 +51,6 @@ if os.name == "posix" and is_ironpython:
     import subprocessdotnet as subprocess
 else:
     import subprocess
-try:
-    import clr
-    from System import Convert
-
-    edb_initialized = True
-except ImportError:
-    if os.name != "posix":
-        warnings.warn(
-            "The clr is missing. Install PythonNET or use an IronPython version if you want to use the EDB module."
-        )
-        edb_initialized = False
 
 
 class Edb(object):
@@ -173,6 +162,11 @@ class Edb(object):
                 if settings.enable_local_log_file and self.log_name:
                     self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
                 self.logger.info("EDB %s was created correctly from %s file.", self.edbpath, edbpath[-2:])
+            elif edbpath.endswith("edb.def"):
+                self.edbpath = os.path.dirname(edbpath)
+                if settings.enable_local_log_file and self.log_name:
+                    self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
+                self.open_edb()
             elif not os.path.exists(os.path.join(self.edbpath, "edb.def")):
                 self.create_edb()
                 if settings.enable_local_log_file and self.log_name:
@@ -190,6 +184,12 @@ class Edb(object):
         else:
             warnings.warn("Failed to initialize DLLs.")
 
+        if not self.materials.materials:
+            self.materials.add_material("air")
+            self.materials.add_material("copper", 1, 0.999991, 5.8e7, 0, 0)
+            self.materials.add_material("fr4_epoxy", 4.4, 1, 0, 0.02, 0)
+            self.materials.add_material("solder_mask", 3.1, 1, 0, 0.035, 0)
+
     def __enter__(self):
         return self
 
@@ -275,22 +275,22 @@ class Edb(object):
                         sys.path.append(edb_path)
                         os.environ[env_value(self.edbversion)] = self.base_path
             if is_ironpython:
-                clr.AddReferenceToFile("Ansys.Ansoft.Edb.dll")
-                clr.AddReferenceToFile("Ansys.Ansoft.EdbBuilderUtils.dll")
-                clr.AddReferenceToFileAndPath(os.path.join(self.base_path, "Ansys.Ansoft.SimSetupData.dll"))
+                _clr.AddReferenceToFile("Ansys.Ansoft.Edb.dll")
+                _clr.AddReferenceToFile("Ansys.Ansoft.EdbBuilderUtils.dll")
+                _clr.AddReferenceToFileAndPath(os.path.join(self.base_path, "Ansys.Ansoft.SimSetupData.dll"))
             else:
-                clr.AddReference("Ansys.Ansoft.Edb")
-                clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
-                clr.AddReference("Ansys.Ansoft.SimSetupData")
+                _clr.AddReference("Ansys.Ansoft.Edb")
+                _clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
+                _clr.AddReference("Ansys.Ansoft.SimSetupData")
         else:
             if self.student_version:
                 self.base_path = env_path_student(self.edbversion)
             else:
                 self.base_path = env_path(self.edbversion)
             sys.path.append(self.base_path)
-            clr.AddReference("Ansys.Ansoft.Edb")
-            clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
-            clr.AddReference("Ansys.Ansoft.SimSetupData")
+            _clr.AddReference("Ansys.Ansoft.Edb")
+            _clr.AddReference("Ansys.Ansoft.EdbBuilderUtils")
+            _clr.AddReference("Ansys.Ansoft.SimSetupData")
         os.environ["ECAD_TRANSLATORS_INSTALL_DIR"] = self.base_path
         oaDirectory = os.path.join(self.base_path, "common", "oa")
         os.environ["ANSYS_OADIR"] = oaDirectory
@@ -308,11 +308,11 @@ class Edb(object):
         """EDB library object containing advanced EDB methods not accessible directly from Python."""
         if not self._edblib:
             if os.name == "posix" and is_ironpython:
-                clr.AddReferenceToFile("EdbLib.dll")
-                clr.AddReferenceToFile("DataModel.dll")
+                _clr.AddReferenceToFile("EdbLib.dll")
+                _clr.AddReferenceToFile("DataModel.dll")
             else:
-                clr.AddReference("EdbLib")
-                clr.AddReference("DataModel")
+                _clr.AddReference("EdbLib")
+                _clr.AddReference("DataModel")
             self._edblib = __import__("EdbLib")
             dllpath = os.path.join(os.path.abspath(os.path.dirname(__file__)), "dlls", "EDBLib")
             try:
@@ -321,6 +321,31 @@ class Edb(object):
                 pass
         return self._edblib
 
+    @property
+    def excitations(self):
+        """Get all layout excitations."""
+        terms = [term for term in list(self._active_layout.Terminals) if int(term.GetBoundaryType()) == 0]
+        terms = [i for i in terms if not i.IsReferenceTerminal()]
+        temp = {}
+        for ter in terms:
+            if "BundleTerminal" in ter.GetType().ToString():
+                temp[ter.GetName()] = ExcitationDifferential(self, ter)
+            else:
+                temp[ter.GetName()] = ExcitationPorts(self, ter)
+        return temp
+
+    @property
+    def sources(self):
+        """Get all layout sources."""
+        terms = [term for term in list(self._active_layout.Terminals) if int(term.GetBoundaryType()) in [3, 4, 7]]
+        return {ter.GetName(): ExcitationSources(self, ter) for ter in terms}
+
+    @property
+    def probes(self):
+        """Get all layout sources."""
+        terms = [term for term in list(self._active_layout.Terminals) if int(term.GetBoundaryType()) in [8]]
+        return {ter.GetName(): ExcitationProbes(self, ter) for ter in terms}
+
     @pyaedt_function_handler()
     def open_edb(self, init_dlls=False):
         """Open EDB.
@@ -823,8 +848,8 @@ class Edb(object):
 
         """
         self._db.Close()
-        if self.log_name:
-            self._global_logger.remove_file_logger(os.path.split(self.log_name)[-1])
+        if self.log_name and settings.enable_local_log_file:
+            self._global_logger.remove_file_logger(os.path.splitext(os.path.split(self.log_name)[-1])[0])
             self._logger = self._global_logger
         time.sleep(2)
         start_time = time.time()
@@ -870,7 +895,7 @@ class Edb(object):
         self._db.SaveAs(fname)
         self.edbpath = self._db.GetDirectory()
         if self.log_name:
-            self._global_logger.remove_file_logger(os.path.split(self.log_name)[-1])
+            self._global_logger.remove_file_logger(os.path.splitext(os.path.split(self.log_name)[-1])[0])
             self._logger = self._global_logger
 
         self.log_name = os.path.join(
@@ -966,6 +991,66 @@ class Edb(object):
         else:
             return False
 
+    def _create_extent(
+        self,
+        net_signals,
+        extent_type,
+        expansion_size,
+        use_round_corner,
+        use_pyaedt_extent=False,
+    ):
+        if extent_type in ["Conforming", self.edb.Geometry.ExtentType.Conforming, 1]:
+
+            if use_pyaedt_extent:
+                _poly = self._create_conformal(net_signals, expansion_size, 1e-12, use_round_corner, expansion_size)
+            else:
+                _poly = self.active_layout.GetExpandedExtentFromNets(
+                    net_signals, self.edb.Geometry.ExtentType.Conforming, expansion_size, False, use_round_corner, 1
+                )
+        elif extent_type in ["Bounding", self.edb.Geometry.ExtentType.BoundingBox, 0]:
+            _poly = self.active_layout.GetExpandedExtentFromNets(
+                net_signals, self.edb.Geometry.ExtentType.BoundingBox, expansion_size, False, use_round_corner, 1
+            )
+        else:
+            if use_pyaedt_extent:
+                _poly = self._create_convex_hull(net_signals, expansion_size, 1e-12, use_round_corner, expansion_size)
+            else:
+                _poly = self.active_layout.GetExpandedExtentFromNets(
+                    net_signals, self.edb.Geometry.ExtentType.Conforming, expansion_size, False, use_round_corner, 1
+                )
+                _poly_list = convert_py_list_to_net_list([_poly])
+                _poly = self.edb.Geometry.PolygonData.GetConvexHullOfPolygons(_poly_list)
+        return _poly
+
+    def _create_conformal(self, net_signals, expansion_size, tolerance, round_corner, round_extension):
+        names = []
+        _polys = []
+        for net in net_signals:
+            names.append(net.GetName())
+        for prim in self.core_primitives.primitives:
+            if prim.net_name in names:
+                _polys.extend(
+                    list(
+                        prim.primitive_object.GetPolygonData().Expand(
+                            expansion_size, tolerance, round_corner, round_extension
+                        )
+                    )
+                )
+        _poly = self.edb.Geometry.PolygonData.Unite(convert_py_list_to_net_list(_polys))[0]
+        return _poly
+
+    def _create_convex_hull(self, net_signals, expansion_size, tolerance, round_corner, round_extension):
+        names = []
+        _polys = []
+        for net in net_signals:
+            names.append(net.GetName())
+        for prim in self.core_primitives.primitives:
+            if prim.net_name in names:
+                _polys.append(prim.primitive_object.GetPolygonData())
+        _poly = self.edb.Geometry.PolygonData.GetConvexHullOfPolygons(convert_py_list_to_net_list(_polys))
+        _poly = _poly.Expand(expansion_size, tolerance, round_corner, round_extension)[0]
+        return _poly
+
     def create_cutout(
         self,
         signal_list=[],
@@ -975,7 +1060,7 @@ class Edb(object):
         use_round_corner=False,
         output_aedb_path=None,
         open_cutout_at_end=True,
-        simulation_setup=None,
+        use_pyaedt_extent_computing=False,
     ):
         """Create a cutout and save it to a new AEDB file.
 
@@ -997,8 +1082,8 @@ class Edb(object):
         open_cutout_at_end : bool, optional
             Whether to open the cutout at the end. The default
             is ``True``.
-        simulation_setup : edb_data.simulation_configuration.SimulationConfiguration object, optional
-            Simulation setup to use to overwrite the other parameters. The default is ``None``.
+        use_pyaedt_extent_computing : bool, optional
+            Whether to use pyaedt extent computing (experimental).
 
         Returns
         -------
@@ -1006,15 +1091,7 @@ class Edb(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-
         expansion_size = self.edb_value(expansion_size).ToDouble()
-        if simulation_setup and isinstance(simulation_setup, SimulationConfiguration):
-            signal_list = simulation_setup.signal_nets
-            reference_list = simulation_setup.power_nets
-            if simulation_setup.cutout_subdesign_type == CutoutSubdesignType.Conformal:
-                extent_type = "Conforming"
-                expansion_size = float(simulation_setup.cutout_subdesign_expansion)
-                use_round_corner = bool(simulation_setup.cutout_subdesign_round_corner)
 
         # validate nets in layout
         net_signals = convert_py_list_to_net_list(
@@ -1025,27 +1102,20 @@ class Edb(object):
             [net for net in list(self.active_layout.Nets) if net.GetName() in reference_list]
         )
 
-        if extent_type == "Conforming":
-            _poly = self.active_layout.GetExpandedExtentFromNets(
-                net_signals, self.edb.Geometry.ExtentType.Conforming, expansion_size, False, use_round_corner, 1
-            )
-        elif extent_type == "Bounding":
-            _poly = self.active_layout.GetExpandedExtentFromNets(
-                net_signals, self.edb.Geometry.ExtentType.BoundingBox, expansion_size, False, use_round_corner, 1
-            )
-        else:
-            _poly = self.active_layout.GetExpandedExtentFromNets(
-                net_signals, self.edb.Geometry.ExtentType.Conforming, expansion_size, False, use_round_corner, 1
-            )
-            _poly_list = convert_py_list_to_net_list([_poly])
-            _poly = self.edb.Geometry.PolygonData.GetConvexHullOfPolygons(_poly_list)
+        _poly = self._create_extent(
+            net_signals,
+            extent_type,
+            expansion_size,
+            use_round_corner,
+            use_pyaedt_extent_computing,
+        )
 
         # Create new cutout cell/design
+        included_nets_list = signal_list + reference_list
         included_nets = convert_py_list_to_net_list(
-            [net for net in list(self.active_layout.Nets) if net.GetName() in signal_list + reference_list]
+            [net for net in list(self.active_layout.Nets) if net.GetName() in included_nets_list]
         )
         _cutout = self.active_cell.CutOut(included_nets, _netsClip, _poly, True)
-
         # Analysis setups do not come over with the clipped design copy,
         # so add the analysis setups from the original here.
         id = 1
@@ -1070,7 +1140,11 @@ class Edb(object):
             _success = db2.Save()
             _dbCells = convert_py_list_to_net_list(_dbCells)
             db2.CopyCells(_dbCells)  # Copies cutout cell/design to db2 project
-            _success = db2.Save()
+            if len(list(db2.CircuitCells)) > 0:
+                for net in list(list(db2.CircuitCells)[0].GetLayout().Nets):
+                    if not net.GetName() in included_nets_list:
+                        net.Delete()
+                _success = db2.Save()
             for c in list(self.db.TopCircuitCells):
                 if c.GetName() == _cutout.GetName():
                     c.Delete()
@@ -1099,6 +1173,225 @@ class Edb(object):
             self._init_objects()
         return True
 
+    @pyaedt_function_handler()
+    def create_cutout_multithread(
+        self,
+        signal_list=[],
+        reference_list=["GND"],
+        extent_type="Conforming",
+        expansion_size=0.002,
+        use_round_corner=False,
+        number_of_threads=4,
+        custom_extent=None,
+        output_aedb_path=None,
+        remove_single_pin_components=False,
+        use_pyaedt_extent_computing=False,
+        extent_defeature=0,
+    ):
+        """Create a cutout using an approach entirely based on pyaedt.
+        It does in sequence:
+        - delete all nets not in list,
+        - create a extent of the nets,
+        - check and delete all vias not in the extent,
+        - check and delete all the primitives not in extent,
+        - check and intersect all the primitives that intersect the extent.
+
+
+        Parameters
+        ----------
+        signal_list : list
+            List of signal strings.
+        reference_list : list, optional
+            List of references to add. The default is ``["GND"]``.
+        extent_type : str, optional
+            Type of the extension. Options are ``"Conforming"``, ``"ConvexHull"``, and
+            ``"Bounding"``. The default is ``"Conforming"``.
+        expansion_size : float, str, optional
+            Expansion size ratio in meters. The default is ``0.002``.
+        use_round_corner : bool, optional
+            Whether to use round corners. The default is ``False``.
+        number_of_threads : int, optional
+            Number of thread to use. Default is 4
+        custom_extent : list, optional
+            Custom extent to use for the cutout. It has to be a list of points [[x1,y1],[x2,y2]....] or
+            Edb PolygonData object. In this case, both signal_list and reference_list will be cut.
+        output_aedb_path : str, optional
+            Full path and name for the new AEDB file. If None, then current aedb will be cutout.
+        remove_single_pin_components : bool, optional
+            Remove all Single Pin RLC after the cutout is completed. Default is `False`.
+        use_pyaedt_extent_computing : bool, optional
+            Whether to use pyaedt extent computing (experimental).
+        extent_defeature : float, optional
+            Defeature the cutout before applying it to produce simpler geometry for mesh (Experimental).
+            It applies only to Conforming bounding box. Default value is ``0`` which disable it.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        Examples
+        --------
+        >>> edb = Edb(r'C:.aedb', edbversion="2022.2")
+        >>> edb.logger.info_timer("Edb Opening")
+        >>> edb.logger.reset_timer()
+        >>> start = time.time()
+        >>> signal_list = []
+        >>> for net in edb.core_nets.nets.keys():
+        >>>      if "3V3" in net:
+        >>>           signal_list.append(net)
+        >>> power_list = ["PGND"]
+        >>> edb.create_cutout_multithread(signal_list=signal_list, reference_list=power_list, extent_type="Conforming")
+        >>> end_time = str((time.time() - start)/60)
+        >>> edb.logger.info("Total pyaedt cutout time in min %s", end_time)
+        >>> edb.core_nets.plot(signal_list, None, color_by_net=True)
+        >>> edb.core_nets.plot(power_list, None, color_by_net=True)
+        >>> edb.save_edb()
+        >>> edb.close_edb()
+
+        """
+        if is_ironpython:  # pragma: no cover
+            self.logger.error("Method working only in Cpython")
+            return False
+        from concurrent.futures import ThreadPoolExecutor
+
+        if output_aedb_path:
+            self.save_edb_as(output_aedb_path)
+
+        expansion_size = self.edb_value(expansion_size).ToDouble()
+
+        self.logger.reset_timer()
+        if custom_extent:
+            reference_list = reference_list + signal_list
+            all_list = reference_list
+        else:
+            all_list = signal_list + reference_list
+
+        for i in self.core_padstack.padstack_instances.values():
+            if i.net_name not in all_list:
+                i.delete()
+        for i in self.core_primitives.primitives:
+            if i.net_name not in all_list:
+                i.delete()
+        for i in self.core_nets.nets.values():
+            if i.name not in all_list:
+                i.net_object.Delete()
+        self.logger.info_timer("Net clean up")
+        self.logger.reset_timer()
+
+        if custom_extent and isinstance(custom_extent, list):
+            plane = self.core_primitives.Shape("polygon", points=custom_extent)
+            _poly = self.core_primitives.shape_to_polygon_data(plane)
+        elif custom_extent:
+            _poly = custom_extent
+        else:
+            net_signals = convert_py_list_to_net_list(
+                [net for net in list(self.active_layout.Nets) if net.GetName() in signal_list]
+            )
+            _poly = self._create_extent(
+                net_signals, extent_type, expansion_size, use_round_corner, use_pyaedt_extent_computing
+            )
+            if extent_type in ["Conforming", self.edb.Geometry.ExtentType.Conforming, 1] and extent_defeature > 0:
+                _poly = _poly.Defeature(extent_defeature)
+
+        self.logger.info_timer("Expanded Net Polygon Creation")
+        self.logger.reset_timer()
+        _poly_list = convert_py_list_to_net_list([_poly])
+        polys = [i for i in self.core_primitives.primitives if not i.is_void]
+        pinsts = [i for i in list(self.core_padstack.padstack_instances.values())]
+        prims_to_delete = []
+        poly_to_create = []
+        pins_to_delete = []
+
+        def get_polygon_data(prim):
+            return prim.primitive_object.GetPolygonData()
+
+        def intersect(poly1, poly2):
+            return list(poly1.Intersect(poly2))
+
+        def subtract(poly, voids):
+            return poly.Subtract(convert_py_list_to_net_list(poly), convert_py_list_to_net_list(voids))
+
+        def clean_prim(prim_1):  # pragma: no cover
+            net = prim_1.net_name
+            if net in reference_list:
+                pdata = get_polygon_data(prim_1)
+                int_data = _poly.GetIntersectionType(pdata)
+                if int_data == 0:
+                    prims_to_delete.append(prim_1)
+                elif int_data != 2:
+                    list_poly = intersect(_poly, pdata)
+                    if list_poly:
+                        voids = prim_1.voids
+                        for p in list_poly:
+                            if p.IsNull():
+                                continue
+                            list_void = []
+                            void_to_subtract = []
+                            if voids:
+                                for void in voids:
+                                    void_pdata = get_polygon_data(void)
+                                    int_data2 = p.GetIntersectionType(void_pdata)
+                                    if int_data2 > 2:
+                                        void_to_subtract.append(void_pdata)
+                                    elif int_data2 == 2:
+                                        list_void.append(void_pdata)
+                                if void_to_subtract:
+                                    polys_cleans = subtract(p, void_to_subtract)
+                                    for polys_clean in polys_cleans:
+                                        if not polys_clean.IsNull():
+                                            void_to_append = [
+                                                v for v in list_void if polys_clean.GetIntersectionType(v) == 2
+                                            ]
+                                            poly_to_create.append([polys_clean, prim_1.layer_name, net, void_to_append])
+                                else:
+                                    poly_to_create.append([p, prim_1.layer_name, net, list_void])
+                            else:
+                                poly_to_create.append([p, prim_1.layer_name, net, list_void])
+
+                    prims_to_delete.append(prim_1)
+
+        def pins_clean(pinst):
+            if pinst.net_name in reference_list and not pinst.in_polygon(_poly, simple_check=True):
+                pins_to_delete.append(pinst)
+
+        with ThreadPoolExecutor(number_of_threads) as pool:
+            pool.map(lambda item: pins_clean(item), pinsts)
+        # for item in pinsts:
+        #     pins_clean(item)
+
+        for pin in pins_to_delete:
+            pin.delete()
+
+        self.logger.info_timer("Padstack Instances removal completed")
+        self.logger.reset_timer()
+
+        with ThreadPoolExecutor(number_of_threads) as pool:
+            pool.map(lambda item: clean_prim(item), polys)
+
+        for el in poly_to_create:
+            self.core_primitives.create_polygon(el[0], el[1], net_name=el[2], voids=el[3])
+
+        for prim in prims_to_delete:
+            prim.delete()
+        self.logger.info_timer("Primitives cleanup completed")
+        self.logger.reset_timer()
+
+        i = 0
+        for comp, val in self.core_components.components.items():
+            if val.numpins == 0:
+                val.edbcomponent.Delete()
+                i += 1
+        if remove_single_pin_components:
+            self.core_components.delete_single_pin_rlc()
+
+        self.core_components.refresh_components()
+        self.logger.info("Deleted {} additional components".format(i))
+
+        self.logger.info_timer("Single Pins components deleted")
+        self.logger.reset_timer()
+        return True
+
     @pyaedt_function_handler()
     def get_conformal_polygon_from_netlist(self, netlist=None):
         """Return an EDB conformal polygon based on a netlist.
@@ -1262,16 +1555,16 @@ class Edb(object):
                 position = self.edb.Geometry.PointData(self.edb_value(p.position[0]), self.edb_value(p.position[1]))
                 net = self.core_nets.find_or_create_net(p.net_name)
                 rotation = self.edb_value(p.rotation)
-                sign_layers = list(self.core_stackup.signal_layers.keys())
+                sign_layers = list(self.stackup.signal_layers.keys())
                 if not p.start_layer:
-                    fromlayer = self.core_stackup.signal_layers[sign_layers[-1]]._layer
+                    fromlayer = self.stackup.signal_layers[sign_layers[-1]]._edb_layer
                 else:
-                    fromlayer = self.core_stackup.signal_layers[p.start_layer]._layer
+                    fromlayer = self.stackup.signal_layers[p.start_layer]._edb_layer
 
                 if not p.stop_layer:
-                    tolayer = self.core_stackup.signal_layers[sign_layers[0]]._layer
+                    tolayer = self.stackup.signal_layers[sign_layers[0]]._edb_layer
                 else:
-                    tolayer = self.core_stackup.signal_layers[p.stop_layer]._layer
+                    tolayer = self.stackup.signal_layers[p.stop_layer]._edb_layer
                 padstack = None
                 for pad in list(self.core_padstack.padstacks.keys()):
                     if pad == p.padstack_definition:
@@ -1311,8 +1604,8 @@ class Edb(object):
                     layout, void_circle.layer_name, void_circle.net, void_circle.primitive_object.GetPolygonData()
                 )
                 cloned_polygon.SetIsNegative(True)
-        layers = self.core_stackup.stackup_layers.signal_layers
-        for layer in list(layers.keys()):
+        layers = [i for i in list(self.stackup.signal_layers.keys())]
+        for layer in layers:
             layer_primitves = self.core_primitives.get_primitives(layer_name=layer)
             if len(layer_primitves) == 0:
                 self.core_primitives.create_polygon(plane, layer, net_name="DUMMY")
@@ -1786,14 +2079,36 @@ class Edb(object):
             self.core_nets.classify_nets(simulation_setup)
             if simulation_setup.do_cutout_subdesign:
                 self.logger.info("Cutting out using method: {0}".format(simulation_setup.cutout_subdesign_type))
-                old_cell_name = self.active_cell.GetName()
-                if self.create_cutout(simulation_setup=simulation_setup, output_aedb_path=simulation_setup.output_aedb):
+                if simulation_setup.use_default_cutout:
+                    old_cell_name = self.active_cell.GetName()
+                    if self.create_cutout(
+                        signal_list=simulation_setup.signal_nets,
+                        reference_list=simulation_setup.power_nets,
+                        expansion_size=simulation_setup.cutout_subdesign_expansion,
+                        use_round_corner=simulation_setup.cutout_subdesign_round_corner,
+                        extent_type=simulation_setup.cutout_subdesign_type,
+                        output_aedb_path=simulation_setup.output_aedb,
+                    ):
+                        self.logger.info("Cutout processed.")
+                        old_cell = self.active_cell.FindByName(
+                            self._db, self.edb.Cell.CellType.CircuitCell, old_cell_name
+                        )
+                        if old_cell:
+                            old_cell.Delete()
+                    else:  # pragma: no cover
+                        self.logger.error("Cutout failed.")
+                else:
+                    self.logger.info("Cutting out using method: {0}".format(simulation_setup.cutout_subdesign_type))
+                    self.create_cutout_multithread(
+                        signal_list=simulation_setup.signal_nets,
+                        reference_list=simulation_setup.power_nets,
+                        expansion_size=simulation_setup.cutout_subdesign_expansion,
+                        use_round_corner=simulation_setup.cutout_subdesign_round_corner,
+                        extent_type=simulation_setup.cutout_subdesign_type,
+                        output_aedb_path=simulation_setup.output_aedb,
+                    )
                     self.logger.info("Cutout processed.")
-                    old_cell = self.active_cell.FindByName(self._db, self.edb.Cell.CellType.CircuitCell, old_cell_name)
-                    if old_cell:
-                        old_cell.Delete()
-                else:  # pragma: no cover
-                    self.logger.error("Cutout failed.")
+
             self.logger.info("Deleting existing ports.")
             map(lambda port: port.Delete(), list(self.active_layout.Terminals))
             map(lambda pg: pg.Delete(), list(self.active_layout.PinGroups))
@@ -1851,3 +2166,44 @@ class Edb(object):
         EDBStatistics object from the loaded layout.
         """
         return self.core_primitives.get_layout_statistics(evaluate_area=compute_area, net_list=None)
+
+    @pyaedt_function_handler()
+    def are_port_reference_terminals_connected(self, common_reference=None):
+        """Check if all terminal references in design are connected.
+        If the reference nets are different, there is no hope for the terminal references to be connected.
+        After we have identified a common reference net we need to loop the terminals again to get
+        the correct reference terminals that uses that net.
+
+        Parameters
+        ----------
+        common_reference : str, optional
+            Common Reference name. If ``None`` it will be searched in ports terminal.
+            If a string is passed then all excitations must have such reference assigned.
+
+        Returns
+        -------
+        bool
+            Either if the ports are connected to reference_name or not.
+        """
+        self.logger.reset_timer()
+        if not common_reference:
+            common_reference = list(
+                set([i.reference_net_name for i in self.excitations.values() if i.reference_net_name])
+            )
+            if len(common_reference) > 1:
+                self.logger.error("More than 1 reference found.")
+            common_reference = common_reference[0]
+        setList = [
+            set(i.reference_object.get_connected_object_id_set())
+            for i in self.excitations.values()
+            if i.reference_net_name == common_reference
+        ]
+
+        # Get the set intersections for all the ID sets.
+        iDintersection = set.intersection(*setList)
+        self.logger.info_timer(
+            "Terminal reference primitive IDs total intersections = {}\n\n".format(len(iDintersection))
+        )
+
+        # If the intersections are non-zero, the termimal references are connected.
+        return True if len(iDintersection) > 0 else False
