@@ -4,9 +4,7 @@
 import codecs
 import json
 import math
-import os
 import re
-import warnings
 
 from pyaedt import _retry_ntimes
 from pyaedt import generate_unique_name
@@ -17,20 +15,13 @@ from pyaedt.edb_core.edb_data.sources import Source
 from pyaedt.edb_core.edb_data.sources import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.edb_core.padstack import EdbPadstacks
+from pyaedt.generic.clr_module import String
+from pyaedt.generic.clr_module import _clr
 from pyaedt.generic.general_methods import get_filename_without_extension
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
 
-try:
-    import clr
-
-    clr.AddReference("System")
-    from System import String
-except ImportError:
-    if os.name != "posix":
-        warnings.warn("This module requires PythonNet.")
-
 
 def resistor_value_parser(RValue):
     """Convert a resistor value.
@@ -651,8 +642,12 @@ class Components(object):
             if not negative_pin_group:  # pragma: no cover
                 return False
             if source.source_type == SourceType.Vsource:  # pragma: no cover
-                positive_pin_group_term = self._create_pin_group_terminal(positive_pin_group)
-                negative_pin_group_term = self._create_pin_group_terminal(negative_pin_group)
+                positive_pin_group_term = self._create_pin_group_terminal(
+                    positive_pin_group, source.positive_node.component
+                )
+                negative_pin_group_term = self._create_pin_group_terminal(
+                    negative_pin_group, source.negative_node.component, isref=True
+                )
                 positive_pin_group_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
                 negative_pin_group_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
                 term_name = source.name
@@ -666,8 +661,12 @@ class Components(object):
                 negative_pin_group_term.SetImpedance(self._get_edb_value(source.impedance))
                 positive_pin_group_term.SetReferenceTerminal(negative_pin_group_term)
             elif source.source_type == SourceType.Isource:  # pragma: no cover
-                positive_pin_group_term = self._create_pin_group_terminal(positive_pin_group)
-                negative_pin_group_term = self._create_pin_group_terminal(negative_pin_group)
+                positive_pin_group_term = self._create_pin_group_terminal(
+                    positive_pin_group, source.positive_node.component
+                )
+                negative_pin_group_term = self._create_pin_group_terminal(
+                    negative_pin_group, source.negative_node.component, isref=True
+                )
                 positive_pin_group_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
                 negative_pin_group_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
                 term_name = source.name
@@ -774,7 +773,7 @@ class Components(object):
                     ref_pin_group = self.create_pingroup_from_pins(ref_pins)
                     if not ref_pin_group:
                         return False
-                    ref_pin_group_term = self._create_pin_group_terminal(ref_pin_group)
+                    ref_pin_group_term = self._create_pin_group_terminal(ref_pin_group, component, isref=True)
                     if not ref_pin_group_term:
                         return False
                 for net in net_list:
@@ -783,7 +782,7 @@ class Components(object):
                         pin_group = self.create_pingroup_from_pins(pins)
                         if not pin_group:
                             return False
-                        pin_group_term = self._create_pin_group_terminal(pin_group)
+                        pin_group_term = self._create_pin_group_terminal(pin_group, component)
                         if pin_group_term:
                             pin_group_term.SetReferenceTerminal(ref_pin_group_term)
                     else:
@@ -962,24 +961,34 @@ class Components(object):
             return True
 
     @pyaedt_function_handler()
-    def _create_pin_group_terminal(self, pingroup, isref=False):
+    def _create_pin_group_terminal(self, pingroup, component=None, isref=False):
         """Creates an EDB pin group terminal from a given EDB pin group.
 
         Parameters
         ----------
         pingroup : Edb pin group.
 
+        component : str or EdbComponent
+
         isref : bool
 
         Returns
         -------
         Edb pin group terminal.
         """
-
-        layout = pingroup.GetLayout()
-        cmp_name = pingroup.GetComponent().GetName()
+        if component:
+            if not isinstance(component, self._edb.Cell.Hierarchy.Component):
+                cmp_name = component
+            else:
+                cmp_name = component.GetName()
+        else:
+            cmp_name = pingroup.GetComponent().GetName()
         net_name = pingroup.GetNet().GetName()
-        term_name = generate_unique_name("Pingroup.{0}.{1}".format(cmp_name, net_name))
+        if cmp_name:
+            term_name = generate_unique_name("{0}.{1}.Pingroup".format(cmp_name, net_name), n=2)
+        else:
+            term_name = generate_unique_name("{0}.Pingroup".format(net_name), n=2)
+
         pingroup_term = self._edb.Cell.Terminal.PinGroupTerminal.Create(
             self._active_layout, pingroup.GetNet(), term_name, pingroup, isref
         )
@@ -1160,6 +1169,7 @@ class Components(object):
         new_cmp.SetPlacementLayer(new_cmp_placement_layer)
         # cmp_transform = System.Activator.CreateInstance(self._edb.Utility.)
         # new_cmp.SetTransform(cmp_transform)
+        self._cmp[new_cmp.GetName()] = EDBComponent(self, new_cmp)
         return new_cmp
         # except:
         #    return (False, None)
@@ -1317,14 +1327,12 @@ class Components(object):
         """
         deleted_comps = []
         for comp, val in self.components.items():
-            if val.numpins < 2 and (val.type == "Resistor" or val.type == "Capacitor" or val.type == "Inductor"):
-                edb_cmp = self.get_component_by_name(comp)
-                if edb_cmp is not None:
-                    edb_cmp.Delete()
-                    deleted_comps.append(comp)
-                    self._pedb._logger.info("Component {} deleted".format(comp))
-        for el in deleted_comps:
-            del self.components[el]
+            if val.numpins < 2 and val.type in ["Resistor", "Capacitor", "Inductor"]:
+                val.edbcomponent.Delete()
+                deleted_comps.append(comp)
+        self.refresh_components()
+        self._pedb._logger.info("Deleted {} components".format(len(deleted_comps)))
+
         return deleted_comps
 
     @pyaedt_function_handler()
@@ -1845,7 +1853,7 @@ class Components(object):
         if isinstance(pin, EDBPadstackInstance):
             pin = pin._edb_padstackinstance
         if is_ironpython:
-            name = clr.Reference[String]()
+            name = _clr.Reference[String]()
             pin.GetProductProperty(self._edb.ProductId.Designer, 11, name)
         else:
             val = String("")
