@@ -269,6 +269,14 @@ class EDBComponent(object):
     def __init__(self, components, cmp):
         self._pcomponents = components
         self.edbcomponent = cmp
+        self._layout_instance = None
+
+    @property
+    def layout_instance(self):
+        """Edb layout instance object."""
+        if self._layout_instance is None:
+            self._layout_instance = self.edbcomponent.GetLayout().GetLayoutInstance()
+        return self._layout_instance
 
     @property
     def _pedb(self):  # pragma: no cover
@@ -529,14 +537,40 @@ class EDBComponent(object):
         -------
         list
         """
-        layinst = self.edbcomponent.GetLayout().GetLayoutInstance()
-        cmpinst = layinst.GetLayoutObjInstance(self.edbcomponent, None)
+        cmpinst = self.layout_instance.GetLayoutObjInstance(self.edbcomponent, None)
         center = cmpinst.GetCenter()
         return [center.X.ToDouble(), center.Y.ToDouble()]
 
+    @property
+    def bounding_box(self):
+        """Component's bounding box.
+
+        Returns
+        -------
+        List[float]
+            List of coordinates for the component's bounding box, with the list of
+            coordinates in this order: [X lower left corner, Y lower left corner,
+            X upper right corner, Y upper right corner].
+        """
+        cmpinst = self.layout_instance.GetLayoutObjInstance(self.edbcomponent, None)
+        bbox = cmpinst.GetBBox()
+        pt1 = bbox.Item1
+        pt2 = bbox.Item2
+        return [pt1.X.ToDouble(), pt1.Y.ToDouble(), pt2.X.ToDouble(), pt2.Y.ToDouble()]
+
+    @property
+    def rotation(self):
+        """Compute the component rotation in radian.
+
+        Returns
+        -------
+        float
+        """
+        return self.edbcomponent.GetTransform().Rotation.ToDouble()
+
     @property
     def pinlist(self):
-        """Pins of Component.
+        """Pins of the component.
 
         Returns
         -------
@@ -546,7 +580,9 @@ class EDBComponent(object):
         pins = [
             p
             for p in self.edbcomponent.LayoutObjs
-            if p.GetObjType() == self._edb.Cell.LayoutObjType.PadstackInstance and p.IsLayoutPin()
+            if p.GetObjType() == self._edb.Cell.LayoutObjType.PadstackInstance
+            and p.IsLayoutPin()
+            and p.GetComponent().GetName() == self.refdes
         ]
         return pins
 
