@@ -1,11 +1,12 @@
 import json
 import os
-import warnings
 from collections import OrderedDict
 
 from pyaedt import generate_unique_name
 from pyaedt.edb_core.edb_data.sources import Source
 from pyaedt.edb_core.edb_data.sources import SourceType
+from pyaedt.generic.clr_module import Dictionary
+from pyaedt.generic.clr_module import String
 from pyaedt.generic.constants import BasisOrder
 from pyaedt.generic.constants import CutoutSubdesignType
 from pyaedt.generic.constants import RadiationBoxType
@@ -14,13 +15,6 @@ from pyaedt.generic.constants import SweepType
 from pyaedt.generic.constants import validate_enum_class_value
 from pyaedt.generic.general_methods import pyaedt_function_handler
 
-try:
-    from System import String
-    from System.Collections.Generic import Dictionary
-except ImportError:
-    if os.name != "posix":
-        warnings.warn("This module requires pythonnet.")
-
 
 class SimulationConfiguration(object):
     """Provides an ASCII simulation configuration file parser.
@@ -105,7 +99,7 @@ class SimulationConfiguration(object):
         self._passivity_tolerance = 0.0001
         self._sweep_name = "Sweep1"
         self._radiation_box = RadiationBoxType.ConvexHull  # 'ConvexHull'
-        self._start_frequency = "0.0GHz"  # 0.0
+        self._start_freq = "0.0GHz"  # 0.0
         self._stop_freq = "10.0GHz"  # 10e9
         self._sweep_type = SweepType.Linear  # 'Linear'
         self._step_freq = "0.025GHz"  # 10e6
@@ -181,6 +175,7 @@ class SimulationConfiguration(object):
         self._sources = []
         self._mesh_sizefactor = 0.0
         self._read_cfg()
+        self._use_default_cutout = True
 
     @property
     def filename(self):  # pragma: no cover
@@ -198,6 +193,20 @@ class SimulationConfiguration(object):
         if isinstance(value, str):  # pragma: no cover
             self._filename = value
 
+    @property
+    def use_default_cutout(self):  # pragma: no cover
+        """Either if use the default EDB Cutout or new pyaedt cutout.
+
+        Returns
+        -------
+        bool
+        """
+        return self._use_default_cutout
+
+    @use_default_cutout.setter
+    def use_default_cutout(self, value):  # pragma: no cover
+        self._use_default_cutout = value
+
     @property
     def generate_solder_balls(self):  # pragma: no cover
         """Retrieve the boolean for applying solder balls.
@@ -559,20 +568,20 @@ class SimulationConfiguration(object):
             self._radiation_box = value
 
     @property
-    def start_frequency(self):  # pragma: no cover
-        """Retrieve starting frequency for the frequency sweep.
+    def start_freq(self):  # pragma: no cover
+        """Starting frequency for the frequency sweep.
 
         Returns
         -------
-            float
-            The value of the frequency point.
+        float
+            Value of the frequency point.
         """
-        return self._start_frequency
+        return self._start_freq
 
-    @start_frequency.setter
-    def start_frequency(self, value):  # pragma: no cover
+    @start_freq.setter
+    def start_freq(self, value):  # pragma: no cover
         if isinstance(value, str):
-            self._start_frequency = value
+            self._start_freq = value
 
     @property
     def stop_freq(self):  # pragma: no cover
@@ -1937,7 +1946,7 @@ class SimulationConfiguration(object):
                                 else:
                                     print("Unprocessed value for RadiationBox '{0}'".format(value))
                             elif i.lower().startswith("startfreq"):
-                                self.start_frequency = value
+                                self.start_freq = value
                             elif i.lower().startswith("stopfreq"):
                                 self.stop_freq = value
                             elif i.lower().startswith("sweeptype"):
