@@ -2,9 +2,8 @@ import os
 import random
 import shutil
 import string
-from glob import glob
-
 from distutils.dir_util import copy_tree
+from glob import glob
 
 
 def my_location():
@@ -92,7 +91,16 @@ class Scratch:
             dst_file = os.path.join(self.path, dst_filename)
         else:
             dst_file = os.path.join(self.path, os.path.basename(src_file))
-        shutil.copy2(src_file, dst_file)
+        if os.path.exists(dst_file):
+            try:
+                os.unlink(dst_file)
+            except OSError:  # pragma: no cover
+                pass
+        try:
+            shutil.copy2(src_file, dst_file)
+        except shutil.SameFileError:  # pragma: no cover
+            pass
+
         return dst_file
 
     def copyfolder(self, src_folder, destfolder):
