@@ -1463,8 +1463,8 @@ class GeometryOperators(object):
         vn : list
             List of ``[x, y, z]`` coordinates for the plane normal.
         right_handed : bool
-            If ``True`` the right-handed rotation from Va to Vb is considered.
-            If ``False`` the left-handed rotation from Va to Vb is considered. The default is ``True`.
+            Whether to consider the right-handed rotation from Va to Vb. The default is ``True``.
+            When ``False``, left-hand rotation from Va to Vb is considered.
 
         Returns
         -------
@@ -1496,14 +1496,13 @@ class GeometryOperators(object):
 
         Parameters
         ----------
-        va : list
+        va : List
             List of ``[x, y]`` coordinates for the first vector.
-        vb : list
+        vb : List
             List of ``[x, y]`` coordinates for the second vector.
-
         right_handed : bool
-            If ``True`` the right-handed rotation from Va to Vb is considered.
-            If ``False`` the left-handed rotation from Va to Vb is considered. The default is ``True`.
+            Whether to consider the right-handed rotation from Va to Vb. The default is ``True``.
+            When ``False``, left-hand rotation from Va to Vb is considered.
 
         Returns
         -------
@@ -1558,7 +1557,7 @@ class GeometryOperators(object):
             asum += a
         if abs(asum) < tol:
             return -1
-        elif abs(asum - 2*math.pi) < tol:
+        elif abs(abs(asum) - 2*math.pi) < tol:
             return 1
         else:  # pragma: no cover
             raise Exception("Unexpected error!")
