@@ -1,11 +1,21 @@
 import json
 import os.path
+import sys
+import warnings
 from collections import OrderedDict
+from difflib import SequenceMatcher
 
 from pyaedt.generic.DataHandlers import _dict2arg
+from pyaedt.generic.DataHandlers import _tuple2dict
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.generic.LoadAEDTFile import load_entire_aedt_file
 
+open3 = open
+if sys.version_info < (3, 0):
+    import io
+
+    open3 = io.open
+
 
 @pyaedt_function_handler()
 def identify_setup(props):
@@ -147,7 +157,7 @@ HFSSSBR = [
     ("RadiationSetup", ""),
     ("PTDUTDSimulationSettings", "None"),
     ("Sweeps", sweepssbr),
-    ("ComputeFarFields", False),
+    ("ComputeFarFields", True),
 ]
 """HFSS SBR+ setup properties and default values."""
 
@@ -1132,24 +1142,24 @@ HFSS3DLayout_ACSimulationSettings = [
     ("SIWDCSettings", HFSS3DLayout_SIWDCSettings),
     ("SIWDCAdvancedSettings", HFSS3DLayout_SIWDCAdvancedSettings),
 ]
-SiwaveDC3DLayout = [
+SiwaveAC3DLayout = [
     ("Properties", HFSS3DLayout_Properties),
     ("CustomSetup", False),
     ("SolveSetupType", "SIwave"),
     ("Color", ["R:=", 0, "G:=", 0, "B:=", 0]),
     ("Position", 0),
     ("SimSetupType", "kSIwave"),
-    ("SimulationSettings", HFSS3DLayout_SimulationSettings),
+    ("SimulationSettings", HFSS3DLayout_ACSimulationSettings),
     ("SweepDataList", HFSS3DLayout_SweepDataList),
 ]
 
-SiwaveAC3DLayout = [
+SiwaveDC3DLayout = [
     ("Properties", HFSS3DLayout_Properties),
     ("CustomSetup", False),
     ("SolveSetupType", "SIwaveDCIR"),
     ("Position", 0),
     ("SimSetupType", "kSIwaveDCIR"),
-    ("SimulationSettings", HFSS3DLayout_ACSimulationSettings),
+    ("SimulationSettings", HFSS3DLayout_SimulationSettings),
     ("SweepDataList", HFSS3DLayout_SweepDataList),
 ]
 
@@ -1317,15 +1327,118 @@ CPSM = [
 TR = []
 
 
+SweepHfss3D = [
+    ("Type", "Interpolating"),
+    ("IsEnabled", True),
+    ("RangeType", "LinearCount"),
+    ("RangeStart", "2.5GHz"),
+    ("RangeEnd", "7.5GHz"),
+    ("SaveSingleField", False),
+    ("RangeCount", 401),
+    ("RangeStep", "1MHz"),
+    ("RangeSamples", 11),
+    ("SaveFields", True),
+    ("SaveRadFields", True),
+    ("GenerateFieldsForAllFreqs", False),
+    ("InterpTolerance", 0.5),
+    ("InterpMaxSolns", 250),
+    ("InterpMinSolns", 0),
+    ("InterpMinSubranges", 1),
+    ("InterpUseS", True),
+    ("InterpUsePortImped", False),
+    ("InterpUsePropConst", True),
+    ("UseDerivativeConvergence", False),
+    ("InterpDerivTolerance", 0.2),
+    ("EnforcePassivity", True),
+    ("UseFullBasis", True),
+    ("PassivityErrorTolerance", 0.0001),
+    ("EnforceCausality", False),
+    ("UseQ3DForDCSolve", False),
+    ("SMatrixOnlySolveMode", "Auto"),
+    ("SMatrixOnlySolveAbove", "1MHz"),
+]
+
+enabled = [("Enable", "true")]
+
+Sweep3DLayout = [
+    ("Properties", enabled),
+    ("Sweeps", SweepDefinition),
+    ("GenerateSurfaceCurrent", False),
+    ("SaveRadFieldsOnly", False),
+    ("ZoSelected", False),
+    ("SAbsError", 0.005),
+    ("ZoPercentError", 1),
+    ("GenerateStateSpace", False),
+    ("EnforcePassivity", True),
+    ("PassivityTolerance", 0.0001),
+    ("UseQ3DForDC", False),
+    ("ResimulateDC", False),
+    ("MaxSolutions", 250),
+    ("InterpUseSMatrix", True),
+    ("InterpUsePortImpedance", True),
+    ("InterpUsePropConst", True),
+    ("InterpUseFullBasis", True),
+    ("AdvDCExtrapolation", False),
+    ("MinSolvedFreq", "0.01GHz"),
+    ("AutoSMatOnlySolve", True),
+    ("MinFreqSMatrixOnlySolve", "1MHz"),
+    ("CustomFrequencyString", ""),
+    ("AllEntries", False),
+    ("AllDiagEntries", False),
+    ("AllOffDiagEntries", False),
+    ("MagMinThreshold", 0.01),
+    ("FreqSweepType", "kInterpolating"),
+]
+
+SweepSiwave = [
+    ("Properties", enabled),
+    ("Sweeps", SweepDefinition),
+    ("Enabled", True),
+    ("FreqSweepType", "kInterpolating"),
+    ("IsDiscrete", False),
+    ("UseQ3DForDC", False),
+    ("SaveFields", False),
+    ("SaveRadFieldsOnly", False),
+    ("RelativeSError", 0.005),
+    ("EnforceCausality", False),
+    ("EnforcePassivity", True),
+    ("PassivityTolerance", 0.0001),
+    ("ComputeDCPoint", False),
+    ("SIwaveWith3DDDM", False),
+    ("UseHFSSSolverRegions", False),
+    ("UseHFSSSolverRegionSchGen", False),
+    ("UseHFSSSolverRegionParallelSolve", False),
+    ("NumParallelHFSSRegions", 1),
+    ("HFSSSolverRegionsSetupName", "<default>"),
+    ("HFSSSolverRegionsSweepName", "<default>"),
+    ("AutoSMatOnlySolve", True),
+    ("MinFreqSMatOnlySolve", "1MHz"),
+    ("MaxSolutions", 250),
+    ("InterpUseSMatrix", True),
+    ("InterpUsePortImpedance", True),
+    ("InterpUsePropConst", True),
+    ("InterpUseFullBasis", True),
+    ("FastSweep", False),
+    ("AdaptiveSampling", False),
+    ("EnforceDCAndCausality", False),
+    ("AdvDCExtrapolation", False),
+    ("MinSolvedFreq", "0.01GHz"),
+    ("MatrixConvEntryList", []),
+    ("HFSSRegionsParallelSimConfig", []),
+]
+
+
 class SweepHFSS(object):
     """Initializes, creates, and updates sweeps in HFSS.
 
     Parameters
     ----------
-    oanalysis :
-
+    app : :class 'pyaedt.modules.SolveSetup.Setup'
+        Setup used for the analysis.
     setupname : str
         Name of the setup.
+    sweepname : str
+        Name of the sweep.
     sweeptype : str, optional
         Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``,
         and ``"Discrete"``. The default is ``"Interpolating"``.
@@ -1333,48 +1446,48 @@ class SweepHFSS(object):
         Dictionary of the properties. The default is ``None``, in which case
         the default properties are retrieved.
 
+    Examples
+    --------
+    >>> hfss = Hfss(specified_version=version, projectname=proj, designname=gtemDesign, solution_type=solutiontype,
+                    setup_name=setupname, new_desktop_session=False, close_on_exit=False)
+    >>> hfss_setup = hfss.setups[0]
+    >>> hfss_sweep = SweepHFSS(hfss_setup, 'Sweep', sweeptype ='Interpolating', props=None)
+
     """
 
-    def __init__(self, app, setupname, sweepname, sweeptype="Interpolating", props=None):
-        self._app = app
-        self.oanalysis = app.omodule
+    def __init__(self, setup, sweepname, sweeptype="Interpolating", props=None, **kwargs):
+        if "app" in kwargs:
+            warnings.warn(
+                "`app` is deprecated since v0.6.22. Use `setup` instead.",
+                DeprecationWarning,
+            )
+            setup = kwargs["app"]
+        if "setupname" in kwargs:
+            warnings.warn(
+                "`setupname` is deprecated since v0.6.22 and not required anymore.",
+                DeprecationWarning,
+            )
+
+        self._app = setup
+        self.oanalysis = setup.omodule
         self.props = {}
-        self.setupname = setupname
+        self.setupname = setup.name
         self.name = sweepname
         if props:
             self.props = props
         else:
-            self.setupname = setupname
-            self.name = sweepname
+            for t in SweepHfss3D:
+                _tuple2dict(t, self.props)
+            if SequenceMatcher(None, sweeptype.lower(), "interpolating").ratio() > 0.8:
+                sweeptype = "Interpolating"
+            elif SequenceMatcher(None, sweeptype.lower(), "discrete").ratio() > 0.8:
+                sweeptype = "Discrete"
+            elif SequenceMatcher(None, sweeptype.lower(), "fast").ratio() > 0.8:
+                sweeptype = "Fast"
+            else:
+                warnings.warn("Invalid sweep type. `Interpolating` will be set as default.")
+                sweeptype = "Interpolating"
             self.props["Type"] = sweeptype
-            self.props["IsEnabled"] = True
-            self.props["RangeType"] = "LinearCount"
-            self.props["RangeStart"] = "2.5GHz"
-            self.props["RangeEnd"] = "7.5GHz"
-            self.props["SaveSingleField"] = False
-            self.props["RangeCount"] = 401
-            self.props["RangeStep"] = "1MHz"
-            self.props["RangeSamples"] = 11
-            self.props["SaveFields"] = True
-            self.props["SaveRadFields"] = True
-            self.props["GenerateFieldsForAllFreqs"] = False
-            self.props["InterpTolerance"] = 0.5
-            self.props["InterpMaxSolns"] = 250
-            self.props["InterpMinSolns"] = 0
-            self.props["InterpMinSubranges"] = 1
-            self.props["InterpUseS"] = True
-            self.props["InterpUsePortImped"] = False
-            self.props["InterpUsePropConst"] = True
-            self.props["UseDerivativeConvergence"] = False
-            self.props["InterpDerivTolerance"] = 0.2
-            self.props["EnforcePassivity"] = True
-            self.props["UseFullBasis"] = True
-            self.props["PassivityErrorTolerance"] = 0.0001
-            self.props["EnforceCausality"] = False
-            self.props["UseQ3DForDCSolve"] = False
-            self.props["SMatrixOnlySolveMode"] = "Auto"
-            self.props["SMatrixOnlySolveAbove"] = "1MHz"
-            self.props["SweepRanges"] = {"Subrange": []}
 
     @property
     def is_solved(self):
@@ -1443,13 +1556,13 @@ class SweepHFSS(object):
 
     @pyaedt_function_handler()
     def add_subrange(self, rangetype, start, end=None, count=None, unit="GHz", save_single_fields=False, clear=False):
-        """Add a subrange to the sweep.
+        """Add a range to the sweep.
 
         Parameters
         ----------
         rangetype : str
-            Type of the subrange. Options are ``"LinearCount"``,
-            ``"LinearStep"``, ``"LogScale"`` and ``"SinglePoints"``.
+            Type of the range. Options are ``"LinearCount"``,
+            ``"LinearStep"``, ``"LogScale"``, and ``"SinglePoints"``.
         start : float
             Starting frequency.
         end : float, optional
@@ -1504,23 +1617,26 @@ class SweepHFSS(object):
             self.props["SweepRanges"] = {"Subrange": []}
             return self.update()
 
-        range = {}
-        range["RangeType"] = rangetype
-        range["RangeStart"] = str(start) + unit
+        interval = {"RangeType": rangetype, "RangeStart": str(start) + unit}
         if rangetype == "LinearCount":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeCount"] = count
+            interval["RangeEnd"] = str(end) + unit
+            interval["RangeCount"] = count
         elif rangetype == "LinearStep":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeStep"] = str(count) + unit
+            interval["RangeEnd"] = str(end) + unit
+            interval["RangeStep"] = str(count) + unit
         elif rangetype == "LogScale":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeCount"] = self.props["RangeCount"]
-            range["RangeSamples"] = count
+            interval["RangeEnd"] = str(end) + unit
+            interval["RangeCount"] = self.props["RangeCount"]
+            interval["RangeSamples"] = count
         elif rangetype == "SinglePoints":
-            range["RangeEnd"] = str(start) + unit
-            range["SaveSingleField"] = save_single_fields
-        self.props["SweepRanges"]["Subrange"].append(range)
+            interval["RangeEnd"] = str(start) + unit
+            interval["SaveSingleField"] = save_single_fields
+        if not self.props.get("SweepRanges", None):
+            self.props["SweepRanges"] = {"Subrange": []}
+
+        if not isinstance(self.props["SweepRanges"]["Subrange"], list):
+            self.props["SweepRanges"]["Subrange"] = [self.props["SweepRanges"]["Subrange"]]
+        self.props["SweepRanges"]["Subrange"].append(interval)
 
         return self.update()
 
@@ -1548,6 +1664,7 @@ class SweepHFSS(object):
 
         """
         self.oanalysis.EditFrequencySweep(self.setupname, self.name, self._get_args())
+
         return True
 
     @pyaedt_function_handler()
@@ -1578,8 +1695,8 @@ class SweepHFSS3DLayout(object):
 
     Parameters
     ----------
-    oanaysis :
-
+    app : :class 'pyaedt.modules.SolveSetup.Setup'
+        Setup used for the analysis.
     setupname : str
         Name of the setup.
     sweepname : str
@@ -1594,59 +1711,43 @@ class SweepHFSS3DLayout(object):
 
     """
 
-    def __init__(
-        self,
-        app,
-        setupname,
-        sweepname,
-        sweeptype="Interpolating",
-        save_fields=True,
-        props=None,
-    ):
-        self._app = app
-        self.oanalysis = app.omodule
+    def __init__(self, setup, sweepname, sweeptype="Interpolating", save_fields=True, props=None, **kwargs):
+
+        if "app" in kwargs:
+            warnings.warn(
+                "`app` is deprecated since v0.6.22. Use `setup` instead.",
+                DeprecationWarning,
+            )
+            setup = kwargs["app"]
+        if "setupname" in kwargs:
+            warnings.warn(
+                "`setupname` is deprecated since v0.6.22 and not required anymore.",
+                DeprecationWarning,
+            )
+
+        self._app = setup
+        self.oanalysis = setup.omodule
         self.props = {}
-        self.setupname = setupname
+        self.setupname = setup.name
         self.name = sweepname
         if props:
             self.props = props
         else:
-            self.setupname = setupname
-            self.name = sweepname
-
-            self.props["Properties"] = OrderedDict({"Enable": True})
-            self.props["Sweeps"] = OrderedDict(
-                {"Variable": "Sweep 1", "Data": "LIN 1Hz 20GHz 0.05GHz", "OffsetF1": False, "Synchronize": 0}
-            )
-            self.props["GenerateSurfaceCurrent"] = save_fields
-            self.props["SaveRadFieldsOnly"] = False
-            if sweeptype == "Interpolating":
-                self.props["FastSweep"] = True
-            elif sweeptype == "Discrete":
-                self.props["FastSweep"] = False
+            if setup.setuptype in [40, 41]:
+                props = SweepSiwave
             else:
-                raise AttributeError("Allowed sweeptype options are 'Interpolating' and 'Discrete'.")
-            # self.props["SaveSingleField"] = False
-            self.props["ZoSelected"] = False
-            self.props["SAbsError"] = 0.005
-            self.props["ZoPercentError"] = 1
-            self.props["GenerateStateSpace"] = False
-            self.props["EnforcePassivity"] = False
-            self.props["PassivityTolerance"] = 0.0001
-            self.props["UseQ3DForDC"] = False
-            self.props["ResimulateDC"] = False
-            self.props["MaxSolutions"] = 250
-            self.props["InterpUseSMatrix"] = True
-            self.props["InterpUsePortImpedance"] = True
-            self.props["InterpUsePropConst"] = True
-            self.props["InterpUseFullBasis"] = True
-            self.props["AdvDCExtrapolation"] = False
-            self.props["MinSolvedFreq"] = "0.01GHz"
-            self.props["CustomFrequencyString"] = ""
-            self.props["AllEntries"] = False
-            self.props["AllDiagEntries"] = False
-            self.props["AllOffDiagEntries"] = False
-            self.props["MagMinThreshold"] = 0.01
+                props = Sweep3DLayout
+            for t in props:
+                _tuple2dict(t, self.props)
+            if SequenceMatcher(None, sweeptype.lower(), "kinterpolating").ratio() > 0.8:
+                sweeptype = "kInterpolating"
+            elif SequenceMatcher(None, sweeptype.lower(), "kdiscrete").ratio() > 0.8:
+                sweeptype = "kDiscrete"
+            else:
+                warnings.warn("Invalid sweep type. `kInterpolating` will be set as default.")
+                sweeptype = "kInterpolating"
+            self.props["FreqSweepType"] = sweeptype
+            self.props["GenerateSurfaceCurrent"] = save_fields
 
     @property
     def combined_name(self):
@@ -1743,24 +1844,29 @@ class SweepHFSS3DLayout(object):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        if rangetype == "SinglePoint" and self.props["FastSweep"]:
-            raise AttributeError("'SinglePoint is allowed only when sweeptype is 'Discrete'.'")
-        if rangetype == "LinearCount" or rangetype == "LinearStep" or rangetype == "LogScale":
-            if not end or not count:
-                raise AttributeError("Parameters 'end' and 'count' must be present.")
+        try:
+            if rangetype == "SinglePoint" and self.props["FreqSweepType"] == "kInterpolating":
+                raise AttributeError("'SinglePoint is allowed only when sweeptype is 'Discrete'.'")
+            if rangetype == "LinearCount" or rangetype == "LinearStep" or rangetype == "LogScale":
+                if not end or not count:
+                    raise AttributeError("Parameters 'end' and 'count' must be present.")
 
-        if rangetype == "LinearCount":
-            sweep_range = " LINC " + str(start) + unit + " " + str(end) + unit + " " + str(count)
-        elif rangetype == "LinearStep":
-            sweep_range = " LIN " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
-        elif rangetype == "LogScale":
-            sweep_range = " DEC " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
-        elif rangetype == "SinglePoint":
-            sweep_range = " " + str(start) + unit
-        else:
-            raise AttributeError('Allowed rangetype are "LinearCount", "SinglePoint", "LinearStep", and "LogScale".')
-        self.props["Sweeps"]["Data"] += sweep_range
-        return self.update()
+            if rangetype == "LinearCount":
+                sweep_range = " LINC " + str(start) + unit + " " + str(end) + unit + " " + str(count)
+            elif rangetype == "LinearStep":
+                sweep_range = " LIN " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
+            elif rangetype == "LogScale":
+                sweep_range = " DEC " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
+            elif rangetype == "SinglePoint":
+                sweep_range = " " + str(start) + unit
+            else:
+                raise AttributeError(
+                    'Allowed rangetype are "LinearCount", "SinglePoint", "LinearStep", and "LogScale".'
+                )
+            self.props["Sweeps"]["Data"] += sweep_range
+            return self.update()
+        except:
+            return False
 
     @pyaedt_function_handler()
     def change_range(self, rangetype, start, end=None, count=None, unit="GHz"):
@@ -1850,14 +1956,14 @@ class SweepHFSS3DLayout(object):
         return arg
 
 
-class SweepQ3D(object):
+class SweepMatrix(object):
     """Initializes, creates, and updates sweeps in Q3D.
 
     Parameters
     ----------
-    oanaysis :
-
-    setupname :str
+    app : :class 'pyaedt.modules.SolveSetup.Setup'
+        Setup used for the analysis.
+    setupname : str
         Name of the setup.
     sweepname : str
         Name of the sweep.
@@ -1870,10 +1976,21 @@ class SweepQ3D(object):
 
     """
 
-    def __init__(self, app, setupname, sweepname, sweeptype="Interpolating", props=None):
-        self._app = app
-        self.oanalysis = app.omodule
-        self.setupname = setupname
+    def __init__(self, setup, sweepname, sweeptype="Interpolating", props=None, **kwargs):
+        if "app" in kwargs:
+            warnings.warn(
+                "`app` is deprecated since v0.6.22. Use `setup` instead.",
+                DeprecationWarning,
+            )
+            setup = kwargs["app"]
+        if "setupname" in kwargs:
+            warnings.warn(
+                "`setupname` is deprecated since v0.6.22 and not required anymore.",
+                DeprecationWarning,
+            )
+        self._app = setup
+        self.oanalysis = setup.omodule
+        self.setupname = setup.name
         self.name = sweepname
         self.props = {}
         if props:
@@ -1917,13 +2034,64 @@ class SweepQ3D(object):
         sol = self._app.p_app.post.reports_by_category.standard(setup_name="{} : {}".format(self.setupname, self.name))
         return True if sol.get_solution_data() else False
 
+    @property
+    def frequencies(self):
+        """Get the list of all frequencies of the active sweep.
+        The project has to be saved and solved to see values.
+
+        Returns
+        -------
+        list of float
+            Frequency points.
+        """
+        sol = self._app.p_app.post.reports_by_category.standard(setup_name="{} : {}".format(self.setupname, self.name))
+        soldata = sol.get_solution_data()
+        if soldata and "Freq" in soldata.intrinsics:
+            return soldata.intrinsics["Freq"]
+        return []
+
+    @property
+    def basis_frequencies(self):
+        """Get the list of all frequencies that have fields available.
+        The project has to be saved and solved to see values.
+
+        Returns
+        -------
+        list of float
+            Frequency points.
+        """
+        solutions_file = os.path.join(self._app.p_app.results_directory, "{}.asol".format(self._app.p_app.design_name))
+        fr = []
+        if os.path.exists(solutions_file):
+            solutions = load_entire_aedt_file(solutions_file)
+            for k, v in solutions.items():
+                if "SolutionBlock" in k and "SolutionName" in v and v["SolutionName"] == self.name and "Fields" in v:
+                    try:
+                        new_list = [float(i) for i in v["Fields"]["IDDblMap"][1::2]]
+                        new_list.sort()
+                        fr.append(new_list)
+                    except (KeyError, NameError, IndexError):
+                        pass
+
+        count = 0
+        for el in self._app.p_app.setups:
+            if el.name == self.setupname:
+                for sweep in el.sweeps:
+                    if sweep.name == self.name:
+                        return fr[count] if len(fr) >= count + 1 else []
+            else:
+                for sweep in el.sweeps:
+                    if sweep.name == self.name:
+                        count += 1
+        return []
+
     @pyaedt_function_handler()
-    def add_subrange(self, type, start, end=None, count=None, unit="GHz", clear=False):
+    def add_subrange(self, rangetype, start, end=None, count=None, unit="GHz", clear=False, **kwargs):
         """Add a subrange to the sweep.
 
         Parameters
         ----------
-        type : str
+        rangetype : str
             Type of the subrange. Options are ``"LinearCount"``,
             ``"LinearStep"``, and ``"LogScale"``.
         start : float
@@ -1943,37 +2111,37 @@ class SweepQ3D(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-
+        if "type" in kwargs:
+            warnings.warn("type has been deprecated. use rangetype.", DeprecationWarning)
+            rangetype = kwargs["type"]
         if clear:
-            self.props["RangeType"] = type
+            self.props["RangeType"] = rangetype
             self.props["RangeStart"] = str(start) + unit
-            if type == "LinearCount":
+            if rangetype == "LinearCount":
                 self.props["RangeEnd"] = str(end) + unit
                 self.props["RangeCount"] = count
-            elif type == "LinearStep":
+            elif rangetype == "LinearStep":
                 self.props["RangeEnd"] = str(end) + unit
                 self.props["RangeStep"] = str(count) + unit
-            elif type == "LogScale":
+            elif rangetype == "LogScale":
                 self.props["RangeEnd"] = str(end) + unit
                 self.props["RangeSamples"] = count
             self.props["SweepRanges"] = {"Subrange": []}
             return self.update()
-        range = {}
-        range["RangeType"] = type
-        range["RangeStart"] = str(start) + unit
-        if type == "LinearCount":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeCount"] = count
-        elif type == "LinearStep":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeStep"] = str(count) + unit
-        elif type == "LogScale":
-            range["RangeEnd"] = str(end) + unit
-            range["RangeCount"] = self.props["RangeCount"]
-            range["RangeSamples"] = count
+        sweep_range = {"RangeType": rangetype, "RangeStart": str(start) + unit}
+        if rangetype == "LinearCount":
+            sweep_range["RangeEnd"] = str(end) + unit
+            sweep_range["RangeCount"] = count
+        elif rangetype == "LinearStep":
+            sweep_range["RangeEnd"] = str(end) + unit
+            sweep_range["RangeStep"] = str(count) + unit
+        elif rangetype == "LogScale":
+            sweep_range["RangeEnd"] = str(end) + unit
+            sweep_range["RangeCount"] = self.props["RangeCount"]
+            sweep_range["RangeSamples"] = count
         if not self.props.get("SweepRanges") or not self.props["SweepRanges"].get("Subrange"):
             self.props["SweepRanges"] = {"Subrange": []}
-        self.props["SweepRanges"]["Subrange"].append(range)
+        self.props["SweepRanges"]["Subrange"].append(sweep_range)
         return self.update()
 
     @pyaedt_function_handler()
@@ -2184,7 +2352,7 @@ class SetupProps(OrderedDict):
         """
         if not file_path.endswith(".json"):
             file_path = file_path + ".json"
-        with open(file_path, "w", encoding="utf-8") as f:
+        with open3(file_path, "w", encoding="utf-8") as f:
             f.write(json.dumps(self, indent=4, ensure_ascii=False))
         return True
 
@@ -2206,7 +2374,7 @@ class SetupProps(OrderedDict):
                 else:
                     set_props(target[k], v)
 
-        with open(file_path, "r", encoding="utf-8") as f:
+        with open3(file_path, "r", encoding="utf-8") as f:
             data = json.load(f)
             set_props(self, data)
         return True
